==> kie-dmn-validation-999-20250203.023502-186-sources.jar: org/kie/dmn/validation/DMNv1x/Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods2.java <==
package org.kie.dmn.validation.DMNv1x;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.kie.dmn.core.util.MsgUtil;
import org.kie.dmn.model.api.DMNElementReference;
import org.kie.dmn.core.impl.DMNMessageImpl;
import org.kie.dmn.api.core.DMNMessage;
import org.kie.dmn.feel.parser.feel11.FEELParser;
import org.kie.dmn.feel.lang.types.BuiltInType;
import org.kie.dmn.core.compiler.DMNCompilerImpl;
import org.kie.dmn.core.compiler.ImportDMNResolverUtil;
import org.kie.dmn.validation.ValidatorUtil;
import org.kie.dmn.model.api.*;
import org.kie.dmn.model.api.DMNElement;
import org.kie.dmn.api.feel.runtime.events.FEELEvent;
import org.kie.dmn.core.util.Msg;
import org.kie.dmn.feel.runtime.events.SyntaxErrorEvent;
import static org.kie.dmn.validation.ValidatorUtil.getRootItemDef;
import static org.kie.dmn.validation.ValidatorUtil.rightOfHash;
import static org.kie.dmn.validation.ValidatorUtil.nameOrIDOfTable;
import static org.kie.dmn.validation.ValidatorUtil.leftOfHash;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;

public class Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods2 {

    /**
     * Rule name: DECISION_MISSING_EXPR
     */
    public static org.drools.model.Rule rule_DECISION__MISSING__EXPR() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Decision> var_$d = D.declarationOf(org.kie.dmn.model.api.Decision.class,
                                                                                                 DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Decision_Metadata_INSTANCE,
                                                                                                 "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DECISION_MISSING_EXPR")
                                      .build(D.pattern(var_$d).expr("GENERATED_8E68DA8B7043D0599C6774E549650534",
                                                                    org.kie.dmn.validation.DMNv1x.P38.LambdaPredicate387563670C999344B492808B48DB946F.INSTANCE,
                                                                    D.reactOn("expression")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PDE.LambdaConsequenceDE3BC52FF83FFB7A832B5E58D31354D9.INSTANCE));
        return rule;
    }

    /**
     * Rule name: DECISION_MISSING_VAR
     */
    public static org.drools.model.Rule rule_DECISION__MISSING__VAR() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Decision> var_$d = D.declarationOf(org.kie.dmn.model.api.Decision.class,
                                                                                                 DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Decision_Metadata_INSTANCE,
                                                                                                 "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DECISION_MISSING_VAR")
                                      .build(D.pattern(var_$d).expr("GENERATED_E71218E652F19A0E04D4C9B541A890ED",
                                                                    org.kie.dmn.validation.DMNv1x.P4C.LambdaPredicate4CC3E256454E59AAE10480BFA3117DA1.INSTANCE,
                                                                    D.reactOn("variable")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PC5.LambdaConsequenceC5B44A94F6341B19A7BD23727C0DE1F0.INSTANCE));
        return rule;
    }

    /**
     * Rule name: DECISION_VAR_MISMATCH
     */
    public static org.drools.model.Rule rule_DECISION__VAR__MISMATCH() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Decision> var_$d = D.declarationOf(org.kie.dmn.model.api.Decision.class,
                                                                                                 DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Decision_Metadata_INSTANCE,
                                                                                                 "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DECISION_VAR_MISMATCH")
                                      .build(D.pattern(var_$d).expr("GENERATED_D3CE9069E3DE7C756C4F0131EF577E08",
                                                                    org.kie.dmn.validation.DMNv1x.P1E.LambdaPredicate1EA6E6EF6116F435EB47C2B015091915.INSTANCE,
                                                                    D.reactOn("variable")).expr("GENERATED_D1F0CA2B7C5867F49DB2E1788CBE7116",
                                                                                                org.kie.dmn.validation.DMNv1x.P5F.LambdaPredicate5F00483A09308C9A549484607C355318.INSTANCE,
                                                                                                D.reactOn("name",
                                                                                                          "variable")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.PA1.LambdaConsequenceA14BA546728F438220085AC3C7FAFB57.INSTANCE));
        return rule;
    }

    /**
     * Rule name: DECISION_PERF_INDICATOR_WRONG_TYPE
     */
    public static org.drools.model.Rule rule_DECISION__PERF__INDICATOR__WRONG__TYPE() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Decision> var_$d = D.declarationOf(org.kie.dmn.model.api.Decision.class,
                                                                                                 DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Decision_Metadata_INSTANCE,
                                                                                                 "$d");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$elemRef = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                                  DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                                  "$elemRef",
                                                                                                                  D.reactiveFrom(var_$d,
                                                                                                                                 org.kie.dmn.validation.DMNv1x.P5D.LambdaExtractor5DF2AAC5776B0E0C9CF7312965668B05.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElement> var_$element = D.declarationOf(org.kie.dmn.model.api.DMNElement.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElement_Metadata_INSTANCE,
                                                                                                         "$element");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DECISION_PERF_INDICATOR_WRONG_TYPE")
                                      .build(D.pattern(var_$d),
                                             D.pattern(var_$elemRef),
                                             D.pattern(var_$element).expr("GENERATED_D0E504FF35A21EB89B9DA2334A730A81",
                                                                          var_$elemRef,
                                                                          org.kie.dmn.validation.DMNv1x.PAF.LambdaPredicateAF6997447CB00D70751A95011EFCCA67.INSTANCE,
                                                                          D.reactOn("id")).expr("GENERATED_38A5B9E427B04DBFE9C0BB5E20A49A4D",
                                                                                                org.kie.dmn.validation.DMNv1x.P33.LambdaPredicate3344589245049099D4676EF9829A1F17.INSTANCE),
                                             D.on(var_$d,
                                                  var_$element,
                                                  var_reporter,
                                                  var_$elemRef).execute(org.kie.dmn.validation.DMNv1x.PF0.LambdaConsequenceF09E137E801B3E21074656E2284CFEA5.INSTANCE));
        return rule;
    }

    /**
     * Rule name: DECISION_DECISION_MAKER_WRONG_TYPE
     */
    public static org.drools.model.Rule rule_DECISION__DECISION__MAKER__WRONG__TYPE() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Decision> var_$d = D.declarationOf(org.kie.dmn.model.api.Decision.class,
                                                                                                 DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Decision_Metadata_INSTANCE,
                                                                                                 "$d");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$elemRef = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                                  DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                                  "$elemRef",
                                                                                                                  D.reactiveFrom(var_$d,
                                                                                                                                 org.kie.dmn.validation.DMNv1x.P9E.LambdaExtractor9EB55657205046CE3C6F47C1A9079984.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElement> var_$element = D.declarationOf(org.kie.dmn.model.api.DMNElement.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElement_Metadata_INSTANCE,
                                                                                                         "$element");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DECISION_DECISION_MAKER_WRONG_TYPE")
                                      .build(D.pattern(var_$d),
                                             D.pattern(var_$elemRef),
                                             D.pattern(var_$element).expr("GENERATED_D0E504FF35A21EB89B9DA2334A730A81",
                                                                          var_$elemRef,
                                                                          org.kie.dmn.validation.DMNv1x.PAF.LambdaPredicateAF6997447CB00D70751A95011EFCCA67.INSTANCE,
                                                                          D.reactOn("id")).expr("GENERATED_9185BF162BD655C2F71CAD82D25C25B3",
                                                                                                org.kie.dmn.validation.DMNv1x.P17.LambdaPredicate173FA45A8140D213C3330A8851D0FE9D.INSTANCE),
                                             D.on(var_$d,
                                                  var_$element,
                                                  var_reporter,
                                                  var_$elemRef).execute(org.kie.dmn.validation.DMNv1x.PF0.LambdaConsequenceF09E137E801B3E21074656E2284CFEA5.INSTANCE));
        return rule;
    }
}

==> kie-dmn-validation-999-20250404.023211-233-sources.jar: org/kie/dmn/validation/DMNv1x/Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods2.java <==
package org.kie.dmn.validation.DMNv1x;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;
import org.kie.dmn.core.util.MsgUtil;
import org.kie.dmn.model.api.DMNElementReference;
import org.kie.dmn.core.impl.DMNMessageImpl;
import org.kie.dmn.api.core.DMNMessage;
import org.kie.dmn.feel.parser.feel11.FEELParser;
import org.kie.dmn.feel.lang.types.BuiltInType;
import org.kie.dmn.core.compiler.DMNCompilerImpl;
import org.kie.dmn.core.compiler.DMNImportsUtil;
import org.kie.dmn.validation.ValidatorUtil;
import org.kie.dmn.model.api.*;
import org.kie.dmn.model.api.DMNElement;
import org.kie.dmn.api.feel.runtime.events.FEELEvent;
import org.kie.dmn.core.util.Msg;
import org.kie.dmn.feel.runtime.events.SyntaxErrorEvent;
import static org.kie.dmn.validation.ValidatorUtil.getRootItemDef;
import static org.kie.dmn.validation.ValidatorUtil.rightOfHash;
import static org.kie.dmn.validation.ValidatorUtil.nameOrIDOfTable;
import static org.kie.dmn.validation.ValidatorUtil.leftOfHash;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;
import static org.kie.dmn.validation.DMNv1x.Rules91573BCE7659DE46F3EF9933A8394CC6.*;

public class Rules91573BCE7659DE46F3EF9933A8394CC6RuleMethods2 {

    /**
     * Rule name: DECISION_MISSING_EXPR
     */
    public static org.drools.model.Rule rule_DECISION__MISSING__EXPR() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Decision> var_$d = D.declarationOf(org.kie.dmn.model.api.Decision.class,
                                                                                                 DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Decision_Metadata_INSTANCE,
                                                                                                 "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DECISION_MISSING_EXPR")
                                      .build(D.pattern(var_$d).expr("GENERATED_8E68DA8B7043D0599C6774E549650534",
                                                                    org.kie.dmn.validation.DMNv1x.P3E.LambdaPredicate3EDD02B8DDF8524348C2A7394556575F.INSTANCE,
                                                                    D.reactOn("expression")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.P27.LambdaConsequence27F669F3D482E451A2F73DB91BC17CBB.INSTANCE));
        return rule;
    }

    /**
     * Rule name: DECISION_MISSING_VAR
     */
    public static org.drools.model.Rule rule_DECISION__MISSING__VAR() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Decision> var_$d = D.declarationOf(org.kie.dmn.model.api.Decision.class,
                                                                                                 DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Decision_Metadata_INSTANCE,
                                                                                                 "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DECISION_MISSING_VAR")
                                      .build(D.pattern(var_$d).expr("GENERATED_E71218E652F19A0E04D4C9B541A890ED",
                                                                    org.kie.dmn.validation.DMNv1x.P2F.LambdaPredicate2F439E5416C27E14EDABA877B70B7614.INSTANCE,
                                                                    D.reactOn("variable")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.P37.LambdaConsequence379631B537219391CC011F0F7DBC2183.INSTANCE));
        return rule;
    }

    /**
     * Rule name: DECISION_VAR_MISMATCH
     */
    public static org.drools.model.Rule rule_DECISION__VAR__MISMATCH() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Decision> var_$d = D.declarationOf(org.kie.dmn.model.api.Decision.class,
                                                                                                 DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Decision_Metadata_INSTANCE,
                                                                                                 "$d");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DECISION_VAR_MISMATCH")
                                      .build(D.pattern(var_$d).expr("GENERATED_D3CE9069E3DE7C756C4F0131EF577E08",
                                                                    org.kie.dmn.validation.DMNv1x.P5B.LambdaPredicate5BD74656412A15939CE540E39023A598.INSTANCE,
                                                                    D.reactOn("variable")).expr("GENERATED_D1F0CA2B7C5867F49DB2E1788CBE7116",
                                                                                                org.kie.dmn.validation.DMNv1x.P37.LambdaPredicate37D190B30BAA8ACE713D3221EBA14A0F.INSTANCE,
                                                                                                D.reactOn("name",
                                                                                                          "variable")),
                                             D.on(var_$d,
                                                  var_reporter).execute(org.kie.dmn.validation.DMNv1x.P0B.LambdaConsequence0BB37706BC72D24AA1499C016351D1FB.INSTANCE));
        return rule;
    }

    /**
     * Rule name: DECISION_PERF_INDICATOR_WRONG_TYPE
     */
    public static org.drools.model.Rule rule_DECISION__PERF__INDICATOR__WRONG__TYPE() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Decision> var_$d = D.declarationOf(org.kie.dmn.model.api.Decision.class,
                                                                                                 DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Decision_Metadata_INSTANCE,
                                                                                                 "$d");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$elemRef = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                                  DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                                  "$elemRef",
                                                                                                                  D.reactiveFrom(var_$d,
                                                                                                                                 org.kie.dmn.validation.DMNv1x.PD6.LambdaExtractorD62A4C8DEE1D74DF6A1726424A7308B7.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElement> var_$element = D.declarationOf(org.kie.dmn.model.api.DMNElement.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElement_Metadata_INSTANCE,
                                                                                                         "$element");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DECISION_PERF_INDICATOR_WRONG_TYPE")
                                      .build(D.pattern(var_$d),
                                             D.pattern(var_$elemRef),
                                             D.pattern(var_$element).expr("GENERATED_D0E504FF35A21EB89B9DA2334A730A81",
                                                                          var_$elemRef,
                                                                          org.kie.dmn.validation.DMNv1x.P86.LambdaPredicate86ECDA1712D0E35508A9515F967A9D3D.INSTANCE,
                                                                          D.reactOn("id")).expr("GENERATED_38A5B9E427B04DBFE9C0BB5E20A49A4D",
                                                                                                org.kie.dmn.validation.DMNv1x.P90.LambdaPredicate9047160362A3EB6413CFEE03962DA4F2.INSTANCE),
                                             D.on(var_$d,
                                                  var_$element,
                                                  var_reporter,
                                                  var_$elemRef).execute(org.kie.dmn.validation.DMNv1x.P6B.LambdaConsequence6B66E7FA730AF930A5AA26B41A81118B.INSTANCE));
        return rule;
    }

    /**
     * Rule name: DECISION_DECISION_MAKER_WRONG_TYPE
     */
    public static org.drools.model.Rule rule_DECISION__DECISION__MAKER__WRONG__TYPE() {
        final org.drools.model.Variable<org.kie.dmn.model.api.Decision> var_$d = D.declarationOf(org.kie.dmn.model.api.Decision.class,
                                                                                                 DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_Decision_Metadata_INSTANCE,
                                                                                                 "$d");
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElementReference> var_$elemRef = D.declarationOf(org.kie.dmn.model.api.DMNElementReference.class,
                                                                                                                  DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElementReference_Metadata_INSTANCE,
                                                                                                                  "$elemRef",
                                                                                                                  D.reactiveFrom(var_$d,
                                                                                                                                 org.kie.dmn.validation.DMNv1x.PE8.LambdaExtractorE85276905E765EA2FD4825148CFA4E69.INSTANCE));
        final org.drools.model.Variable<org.kie.dmn.model.api.DMNElement> var_$element = D.declarationOf(org.kie.dmn.model.api.DMNElement.class,
                                                                                                         DomainClassesMetadata91573BCE7659DE46F3EF9933A8394CC6.org_kie_dmn_model_api_DMNElement_Metadata_INSTANCE,
                                                                                                         "$element");
        org.drools.model.Rule rule = D.rule("org.kie.dmn.validation.DMNv1x",
                                            "DECISION_DECISION_MAKER_WRONG_TYPE")
                                      .build(D.pattern(var_$d),
                                             D.pattern(var_$elemRef),
                                             D.pattern(var_$element).expr("GENERATED_D0E504FF35A21EB89B9DA2334A730A81",
                                                                          var_$elemRef,
                                                                          org.kie.dmn.validation.DMNv1x.P86.LambdaPredicate86ECDA1712D0E35508A9515F967A9D3D.INSTANCE,
                                                                          D.reactOn("id")).expr("GENERATED_9185BF162BD655C2F71CAD82D25C25B3",
                                                                                                org.kie.dmn.validation.DMNv1x.P03.LambdaPredicate032D9D8758D893A713C03EB7709F63C1.INSTANCE),
                                             D.on(var_$d,
                                                  var_$element,
                                                  var_reporter,
                                                  var_$elemRef).execute(org.kie.dmn.validation.DMNv1x.P6B.LambdaConsequence6B66E7FA730AF930A5AA26B41A81118B.INSTANCE));
        return rule;
    }
}
